# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DiscoveryJobArgs', 'DiscoveryJob']

@pulumi.input_type
class DiscoveryJobArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 discovery_details: pulumi.Input['DiscoveryJobDiscoveryDetailsArgs'],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 discovery_client: Optional[pulumi.Input[str]] = None,
                 discovery_type: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 should_propagate_tags_to_discovered_resources: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a DiscoveryJob resource.
        :param pulumi.Input[str] compartment_id: The OCID of Compartment
        :param pulumi.Input['DiscoveryJobDiscoveryDetailsArgs'] discovery_details: The request of DiscoveryJob Resource details.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] discovery_client: Client who submits discovery job.
        :param pulumi.Input[str] discovery_type: Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] should_propagate_tags_to_discovered_resources: If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "discovery_details", discovery_details)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if discovery_client is not None:
            pulumi.set(__self__, "discovery_client", discovery_client)
        if discovery_type is not None:
            pulumi.set(__self__, "discovery_type", discovery_type)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if should_propagate_tags_to_discovered_resources is not None:
            pulumi.set(__self__, "should_propagate_tags_to_discovered_resources", should_propagate_tags_to_discovered_resources)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        The OCID of Compartment
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="discoveryDetails")
    def discovery_details(self) -> pulumi.Input['DiscoveryJobDiscoveryDetailsArgs']:
        """
        The request of DiscoveryJob Resource details.
        """
        return pulumi.get(self, "discovery_details")

    @discovery_details.setter
    def discovery_details(self, value: pulumi.Input['DiscoveryJobDiscoveryDetailsArgs']):
        pulumi.set(self, "discovery_details", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="discoveryClient")
    def discovery_client(self) -> Optional[pulumi.Input[str]]:
        """
        Client who submits discovery job.
        """
        return pulumi.get(self, "discovery_client")

    @discovery_client.setter
    def discovery_client(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "discovery_client", value)

    @property
    @pulumi.getter(name="discoveryType")
    def discovery_type(self) -> Optional[pulumi.Input[str]]:
        """
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        """
        return pulumi.get(self, "discovery_type")

    @discovery_type.setter
    def discovery_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "discovery_type", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="shouldPropagateTagsToDiscoveredResources")
    def should_propagate_tags_to_discovered_resources(self) -> Optional[pulumi.Input[bool]]:
        """
        If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "should_propagate_tags_to_discovered_resources")

    @should_propagate_tags_to_discovered_resources.setter
    def should_propagate_tags_to_discovered_resources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "should_propagate_tags_to_discovered_resources", value)


@pulumi.input_type
class _DiscoveryJobState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 discovery_client: Optional[pulumi.Input[str]] = None,
                 discovery_details: Optional[pulumi.Input['DiscoveryJobDiscoveryDetailsArgs']] = None,
                 discovery_type: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 should_propagate_tags_to_discovered_resources: Optional[pulumi.Input[bool]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 status_message: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DiscoveryJob resources.
        :param pulumi.Input[str] compartment_id: The OCID of Compartment
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] discovery_client: Client who submits discovery job.
        :param pulumi.Input['DiscoveryJobDiscoveryDetailsArgs'] discovery_details: The request of DiscoveryJob Resource details.
        :param pulumi.Input[str] discovery_type: Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] should_propagate_tags_to_discovered_resources: If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] state: The current state of the DiscoveryJob Resource.
        :param pulumi.Input[str] status: Specifies the status of the discovery job
        :param pulumi.Input[str] status_message: The short summary of the status of the discovery job
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] tenant_id: The OCID of Tenant
        :param pulumi.Input[str] time_updated: The time the discovery Job was updated.
        :param pulumi.Input[str] user_id: The OCID of user in which the job is submitted
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if discovery_client is not None:
            pulumi.set(__self__, "discovery_client", discovery_client)
        if discovery_details is not None:
            pulumi.set(__self__, "discovery_details", discovery_details)
        if discovery_type is not None:
            pulumi.set(__self__, "discovery_type", discovery_type)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if should_propagate_tags_to_discovered_resources is not None:
            pulumi.set(__self__, "should_propagate_tags_to_discovered_resources", should_propagate_tags_to_discovered_resources)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if status_message is not None:
            pulumi.set(__self__, "status_message", status_message)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of Compartment
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="discoveryClient")
    def discovery_client(self) -> Optional[pulumi.Input[str]]:
        """
        Client who submits discovery job.
        """
        return pulumi.get(self, "discovery_client")

    @discovery_client.setter
    def discovery_client(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "discovery_client", value)

    @property
    @pulumi.getter(name="discoveryDetails")
    def discovery_details(self) -> Optional[pulumi.Input['DiscoveryJobDiscoveryDetailsArgs']]:
        """
        The request of DiscoveryJob Resource details.
        """
        return pulumi.get(self, "discovery_details")

    @discovery_details.setter
    def discovery_details(self, value: Optional[pulumi.Input['DiscoveryJobDiscoveryDetailsArgs']]):
        pulumi.set(self, "discovery_details", value)

    @property
    @pulumi.getter(name="discoveryType")
    def discovery_type(self) -> Optional[pulumi.Input[str]]:
        """
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        """
        return pulumi.get(self, "discovery_type")

    @discovery_type.setter
    def discovery_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "discovery_type", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="shouldPropagateTagsToDiscoveredResources")
    def should_propagate_tags_to_discovered_resources(self) -> Optional[pulumi.Input[bool]]:
        """
        If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "should_propagate_tags_to_discovered_resources")

    @should_propagate_tags_to_discovered_resources.setter
    def should_propagate_tags_to_discovered_resources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "should_propagate_tags_to_discovered_resources", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the DiscoveryJob Resource.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the status of the discovery job
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> Optional[pulumi.Input[str]]:
        """
        The short summary of the status of the discovery job
        """
        return pulumi.get(self, "status_message")

    @status_message.setter
    def status_message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status_message", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of Tenant
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time the discovery Job was updated.
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of user in which the job is submitted
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class DiscoveryJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 discovery_client: Optional[pulumi.Input[str]] = None,
                 discovery_details: Optional[pulumi.Input[pulumi.InputType['DiscoveryJobDiscoveryDetailsArgs']]] = None,
                 discovery_type: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 should_propagate_tags_to_discovered_resources: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        This resource provides the Discovery Job resource in Oracle Cloud Infrastructure Stack Monitoring service.

        API to create discovery Job and submit discovery Details to agent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_discovery_job = oci.stack_monitoring.DiscoveryJob("testDiscoveryJob",
            compartment_id=var["compartment_id"],
            discovery_details=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsArgs(
                agent_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                properties=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsPropertiesArgs(
                    properties_map=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                resource_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                resource_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                credentials=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsCredentialsArgs(
                    items=[oci.stack_monitoring.DiscoveryJobDiscoveryDetailsCredentialsItemArgs(
                        credential_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        credential_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        properties=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsCredentialsItemPropertiesArgs(
                            properties_map=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    )],
                ),
                tags=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsTagsArgs(
                    properties_map=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
            ),
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            discovery_client=var["discovery_job_discovery_client"],
            discovery_type=var["discovery_job_discovery_type"],
            freeform_tags={
                "bar-key": "value",
            },
            should_propagate_tags_to_discovered_resources=var["discovery_job_should_propagate_tags_to_discovered_resources"])
        ```

        ## Import

        DiscoveryJobs can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/discoveryJob:DiscoveryJob test_discovery_job "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of Compartment
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] discovery_client: Client who submits discovery job.
        :param pulumi.Input[pulumi.InputType['DiscoveryJobDiscoveryDetailsArgs']] discovery_details: The request of DiscoveryJob Resource details.
        :param pulumi.Input[str] discovery_type: Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] should_propagate_tags_to_discovered_resources: If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DiscoveryJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Discovery Job resource in Oracle Cloud Infrastructure Stack Monitoring service.

        API to create discovery Job and submit discovery Details to agent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_discovery_job = oci.stack_monitoring.DiscoveryJob("testDiscoveryJob",
            compartment_id=var["compartment_id"],
            discovery_details=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsArgs(
                agent_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                properties=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsPropertiesArgs(
                    properties_map=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                resource_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                resource_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                credentials=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsCredentialsArgs(
                    items=[oci.stack_monitoring.DiscoveryJobDiscoveryDetailsCredentialsItemArgs(
                        credential_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        credential_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        properties=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsCredentialsItemPropertiesArgs(
                            properties_map=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    )],
                ),
                tags=oci.stack_monitoring.DiscoveryJobDiscoveryDetailsTagsArgs(
                    properties_map=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
            ),
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            discovery_client=var["discovery_job_discovery_client"],
            discovery_type=var["discovery_job_discovery_type"],
            freeform_tags={
                "bar-key": "value",
            },
            should_propagate_tags_to_discovered_resources=var["discovery_job_should_propagate_tags_to_discovered_resources"])
        ```

        ## Import

        DiscoveryJobs can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/discoveryJob:DiscoveryJob test_discovery_job "id"
        ```

        :param str resource_name: The name of the resource.
        :param DiscoveryJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DiscoveryJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 discovery_client: Optional[pulumi.Input[str]] = None,
                 discovery_details: Optional[pulumi.Input[pulumi.InputType['DiscoveryJobDiscoveryDetailsArgs']]] = None,
                 discovery_type: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 should_propagate_tags_to_discovered_resources: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DiscoveryJobArgs.__new__(DiscoveryJobArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["discovery_client"] = discovery_client
            if discovery_details is None and not opts.urn:
                raise TypeError("Missing required property 'discovery_details'")
            __props__.__dict__["discovery_details"] = discovery_details
            __props__.__dict__["discovery_type"] = discovery_type
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["should_propagate_tags_to_discovered_resources"] = should_propagate_tags_to_discovered_resources
            __props__.__dict__["state"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["status_message"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["tenant_id"] = None
            __props__.__dict__["time_updated"] = None
            __props__.__dict__["user_id"] = None
        super(DiscoveryJob, __self__).__init__(
            'oci:StackMonitoring/discoveryJob:DiscoveryJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            discovery_client: Optional[pulumi.Input[str]] = None,
            discovery_details: Optional[pulumi.Input[pulumi.InputType['DiscoveryJobDiscoveryDetailsArgs']]] = None,
            discovery_type: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            should_propagate_tags_to_discovered_resources: Optional[pulumi.Input[bool]] = None,
            state: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            status_message: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            tenant_id: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'DiscoveryJob':
        """
        Get an existing DiscoveryJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of Compartment
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] discovery_client: Client who submits discovery job.
        :param pulumi.Input[pulumi.InputType['DiscoveryJobDiscoveryDetailsArgs']] discovery_details: The request of DiscoveryJob Resource details.
        :param pulumi.Input[str] discovery_type: Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] should_propagate_tags_to_discovered_resources: If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] state: The current state of the DiscoveryJob Resource.
        :param pulumi.Input[str] status: Specifies the status of the discovery job
        :param pulumi.Input[str] status_message: The short summary of the status of the discovery job
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] tenant_id: The OCID of Tenant
        :param pulumi.Input[str] time_updated: The time the discovery Job was updated.
        :param pulumi.Input[str] user_id: The OCID of user in which the job is submitted
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DiscoveryJobState.__new__(_DiscoveryJobState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["discovery_client"] = discovery_client
        __props__.__dict__["discovery_details"] = discovery_details
        __props__.__dict__["discovery_type"] = discovery_type
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["should_propagate_tags_to_discovered_resources"] = should_propagate_tags_to_discovered_resources
        __props__.__dict__["state"] = state
        __props__.__dict__["status"] = status
        __props__.__dict__["status_message"] = status_message
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["tenant_id"] = tenant_id
        __props__.__dict__["time_updated"] = time_updated
        __props__.__dict__["user_id"] = user_id
        return DiscoveryJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of Compartment
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="discoveryClient")
    def discovery_client(self) -> pulumi.Output[str]:
        """
        Client who submits discovery job.
        """
        return pulumi.get(self, "discovery_client")

    @property
    @pulumi.getter(name="discoveryDetails")
    def discovery_details(self) -> pulumi.Output['outputs.DiscoveryJobDiscoveryDetails']:
        """
        The request of DiscoveryJob Resource details.
        """
        return pulumi.get(self, "discovery_details")

    @property
    @pulumi.getter(name="discoveryType")
    def discovery_type(self) -> pulumi.Output[Optional[str]]:
        """
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        """
        return pulumi.get(self, "discovery_type")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="shouldPropagateTagsToDiscoveredResources")
    def should_propagate_tags_to_discovered_resources(self) -> pulumi.Output[bool]:
        """
        If this parameter set to true, the specified tags will be applied  to all resources discovered in the current request.  Default is true. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "should_propagate_tags_to_discovered_resources")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the DiscoveryJob Resource.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Specifies the status of the discovery job
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> pulumi.Output[str]:
        """
        The short summary of the status of the discovery job
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[str]:
        """
        The OCID of Tenant
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time the discovery Job was updated.
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        The OCID of user in which the job is submitted
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetLogAnalyticsEntitiesResult',
    'AwaitableGetLogAnalyticsEntitiesResult',
    'get_log_analytics_entities',
    'get_log_analytics_entities_output',
]

@pulumi.output_type
class GetLogAnalyticsEntitiesResult:
    """
    A collection of values returned by getLogAnalyticsEntities.
    """
    def __init__(__self__, cloud_resource_id=None, compartment_id=None, entity_type_names=None, filters=None, hostname=None, hostname_contains=None, id=None, is_management_agent_id_null=None, lifecycle_details_contains=None, log_analytics_entity_collections=None, name=None, name_contains=None, namespace=None, source_id=None, state=None):
        if cloud_resource_id and not isinstance(cloud_resource_id, str):
            raise TypeError("Expected argument 'cloud_resource_id' to be a str")
        pulumi.set(__self__, "cloud_resource_id", cloud_resource_id)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if entity_type_names and not isinstance(entity_type_names, list):
            raise TypeError("Expected argument 'entity_type_names' to be a list")
        pulumi.set(__self__, "entity_type_names", entity_type_names)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if hostname_contains and not isinstance(hostname_contains, str):
            raise TypeError("Expected argument 'hostname_contains' to be a str")
        pulumi.set(__self__, "hostname_contains", hostname_contains)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_management_agent_id_null and not isinstance(is_management_agent_id_null, str):
            raise TypeError("Expected argument 'is_management_agent_id_null' to be a str")
        pulumi.set(__self__, "is_management_agent_id_null", is_management_agent_id_null)
        if lifecycle_details_contains and not isinstance(lifecycle_details_contains, str):
            raise TypeError("Expected argument 'lifecycle_details_contains' to be a str")
        pulumi.set(__self__, "lifecycle_details_contains", lifecycle_details_contains)
        if log_analytics_entity_collections and not isinstance(log_analytics_entity_collections, list):
            raise TypeError("Expected argument 'log_analytics_entity_collections' to be a list")
        pulumi.set(__self__, "log_analytics_entity_collections", log_analytics_entity_collections)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if name_contains and not isinstance(name_contains, str):
            raise TypeError("Expected argument 'name_contains' to be a str")
        pulumi.set(__self__, "name_contains", name_contains)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if source_id and not isinstance(source_id, str):
            raise TypeError("Expected argument 'source_id' to be a str")
        pulumi.set(__self__, "source_id", source_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="cloudResourceId")
    def cloud_resource_id(self) -> Optional[str]:
        """
        The OCID of the Cloud resource which this entity is a representation of. This may be blank when the entity represents a non-cloud resource that the customer may have on their premises.
        """
        return pulumi.get(self, "cloud_resource_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier [OCID] (https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="entityTypeNames")
    def entity_type_names(self) -> Optional[Sequence[str]]:
        """
        Log analytics entity type name.
        """
        return pulumi.get(self, "entity_type_names")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetLogAnalyticsEntitiesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def hostname(self) -> Optional[str]:
        """
        The hostname where the entity represented here is actually present. This would be the output one would get if they run `echo $HOSTNAME` on Linux or an equivalent OS command. This may be different from management agents host since logs may be collected remotely.
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter(name="hostnameContains")
    def hostname_contains(self) -> Optional[str]:
        return pulumi.get(self, "hostname_contains")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isManagementAgentIdNull")
    def is_management_agent_id_null(self) -> Optional[str]:
        return pulumi.get(self, "is_management_agent_id_null")

    @property
    @pulumi.getter(name="lifecycleDetailsContains")
    def lifecycle_details_contains(self) -> Optional[str]:
        return pulumi.get(self, "lifecycle_details_contains")

    @property
    @pulumi.getter(name="logAnalyticsEntityCollections")
    def log_analytics_entity_collections(self) -> Sequence['outputs.GetLogAnalyticsEntitiesLogAnalyticsEntityCollectionResult']:
        """
        The list of log_analytics_entity_collection.
        """
        return pulumi.get(self, "log_analytics_entity_collections")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Log analytics entity name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> Optional[str]:
        return pulumi.get(self, "name_contains")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> Optional[str]:
        """
        This indicates the type of source. It is primarily for Enterprise Manager Repository ID.
        """
        return pulumi.get(self, "source_id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the log analytics entity.
        """
        return pulumi.get(self, "state")


class AwaitableGetLogAnalyticsEntitiesResult(GetLogAnalyticsEntitiesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogAnalyticsEntitiesResult(
            cloud_resource_id=self.cloud_resource_id,
            compartment_id=self.compartment_id,
            entity_type_names=self.entity_type_names,
            filters=self.filters,
            hostname=self.hostname,
            hostname_contains=self.hostname_contains,
            id=self.id,
            is_management_agent_id_null=self.is_management_agent_id_null,
            lifecycle_details_contains=self.lifecycle_details_contains,
            log_analytics_entity_collections=self.log_analytics_entity_collections,
            name=self.name,
            name_contains=self.name_contains,
            namespace=self.namespace,
            source_id=self.source_id,
            state=self.state)


def get_log_analytics_entities(cloud_resource_id: Optional[str] = None,
                               compartment_id: Optional[str] = None,
                               entity_type_names: Optional[Sequence[str]] = None,
                               filters: Optional[Sequence[pulumi.InputType['GetLogAnalyticsEntitiesFilterArgs']]] = None,
                               hostname: Optional[str] = None,
                               hostname_contains: Optional[str] = None,
                               is_management_agent_id_null: Optional[str] = None,
                               lifecycle_details_contains: Optional[str] = None,
                               name: Optional[str] = None,
                               name_contains: Optional[str] = None,
                               namespace: Optional[str] = None,
                               source_id: Optional[str] = None,
                               state: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogAnalyticsEntitiesResult:
    """
    This data source provides the list of Log Analytics Entities in Oracle Cloud Infrastructure Log Analytics service.

    Return a list of log analytics entities.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_log_analytics_entities = oci.LogAnalytics.get_log_analytics_entities(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        cloud_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        entity_type_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        hostname=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        hostname_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_management_agent_id_null=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        lifecycle_details_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str cloud_resource_id: A filter to return only log analytics entities whose cloudResourceId matches the cloudResourceId given.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param Sequence[str] entity_type_names: A filter to return only log analytics entities whose entityTypeName matches the entire log analytics entity type name of one of the entityTypeNames given in the list. The match is case-insensitive.
    :param str hostname: A filter to return only log analytics entities whose hostname matches the entire hostname given.
    :param str hostname_contains: A filter to return only log analytics entities whose hostname contains the substring given. The match is case-insensitive.
    :param str is_management_agent_id_null: A filter to return only those log analytics entities whose managementAgentId is null or is not null.
    :param str lifecycle_details_contains: A filter to return only log analytics entities whose lifecycleDetails contains the specified string.
    :param str name: A filter to return only log analytics entities whose name matches the entire name given. The match is case-insensitive.
    :param str name_contains: A filter to return only log analytics entities whose name contains the name given. The match is case-insensitive.
    :param str namespace: The Logging Analytics namespace used for the request.
    :param str source_id: A filter to return only log analytics entities whose sourceId matches the sourceId given.
    :param str state: A filter to return only those log analytics entities with the specified lifecycle state. The state value is case-insensitive.
    """
    __args__ = dict()
    __args__['cloudResourceId'] = cloud_resource_id
    __args__['compartmentId'] = compartment_id
    __args__['entityTypeNames'] = entity_type_names
    __args__['filters'] = filters
    __args__['hostname'] = hostname
    __args__['hostnameContains'] = hostname_contains
    __args__['isManagementAgentIdNull'] = is_management_agent_id_null
    __args__['lifecycleDetailsContains'] = lifecycle_details_contains
    __args__['name'] = name
    __args__['nameContains'] = name_contains
    __args__['namespace'] = namespace
    __args__['sourceId'] = source_id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:LogAnalytics/getLogAnalyticsEntities:getLogAnalyticsEntities', __args__, opts=opts, typ=GetLogAnalyticsEntitiesResult).value

    return AwaitableGetLogAnalyticsEntitiesResult(
        cloud_resource_id=__ret__.cloud_resource_id,
        compartment_id=__ret__.compartment_id,
        entity_type_names=__ret__.entity_type_names,
        filters=__ret__.filters,
        hostname=__ret__.hostname,
        hostname_contains=__ret__.hostname_contains,
        id=__ret__.id,
        is_management_agent_id_null=__ret__.is_management_agent_id_null,
        lifecycle_details_contains=__ret__.lifecycle_details_contains,
        log_analytics_entity_collections=__ret__.log_analytics_entity_collections,
        name=__ret__.name,
        name_contains=__ret__.name_contains,
        namespace=__ret__.namespace,
        source_id=__ret__.source_id,
        state=__ret__.state)


@_utilities.lift_output_func(get_log_analytics_entities)
def get_log_analytics_entities_output(cloud_resource_id: Optional[pulumi.Input[Optional[str]]] = None,
                                      compartment_id: Optional[pulumi.Input[str]] = None,
                                      entity_type_names: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetLogAnalyticsEntitiesFilterArgs']]]]] = None,
                                      hostname: Optional[pulumi.Input[Optional[str]]] = None,
                                      hostname_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                      is_management_agent_id_null: Optional[pulumi.Input[Optional[str]]] = None,
                                      lifecycle_details_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                      name: Optional[pulumi.Input[Optional[str]]] = None,
                                      name_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                      namespace: Optional[pulumi.Input[str]] = None,
                                      source_id: Optional[pulumi.Input[Optional[str]]] = None,
                                      state: Optional[pulumi.Input[Optional[str]]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLogAnalyticsEntitiesResult]:
    """
    This data source provides the list of Log Analytics Entities in Oracle Cloud Infrastructure Log Analytics service.

    Return a list of log analytics entities.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_log_analytics_entities = oci.LogAnalytics.get_log_analytics_entities(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        cloud_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        entity_type_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        hostname=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        hostname_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_management_agent_id_null=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        lifecycle_details_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str cloud_resource_id: A filter to return only log analytics entities whose cloudResourceId matches the cloudResourceId given.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param Sequence[str] entity_type_names: A filter to return only log analytics entities whose entityTypeName matches the entire log analytics entity type name of one of the entityTypeNames given in the list. The match is case-insensitive.
    :param str hostname: A filter to return only log analytics entities whose hostname matches the entire hostname given.
    :param str hostname_contains: A filter to return only log analytics entities whose hostname contains the substring given. The match is case-insensitive.
    :param str is_management_agent_id_null: A filter to return only those log analytics entities whose managementAgentId is null or is not null.
    :param str lifecycle_details_contains: A filter to return only log analytics entities whose lifecycleDetails contains the specified string.
    :param str name: A filter to return only log analytics entities whose name matches the entire name given. The match is case-insensitive.
    :param str name_contains: A filter to return only log analytics entities whose name contains the name given. The match is case-insensitive.
    :param str namespace: The Logging Analytics namespace used for the request.
    :param str source_id: A filter to return only log analytics entities whose sourceId matches the sourceId given.
    :param str state: A filter to return only those log analytics entities with the specified lifecycle state. The state value is case-insensitive.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetSteeringPolicyResult',
    'AwaitableGetSteeringPolicyResult',
    'get_steering_policy',
    'get_steering_policy_output',
]

@pulumi.output_type
class GetSteeringPolicyResult:
    """
    A collection of values returned by getSteeringPolicy.
    """
    def __init__(__self__, answers=None, compartment_id=None, defined_tags=None, display_name=None, freeform_tags=None, health_check_monitor_id=None, id=None, rules=None, self=None, state=None, steering_policy_id=None, template=None, time_created=None, ttl=None):
        if answers and not isinstance(answers, list):
            raise TypeError("Expected argument 'answers' to be a list")
        pulumi.set(__self__, "answers", answers)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if health_check_monitor_id and not isinstance(health_check_monitor_id, str):
            raise TypeError("Expected argument 'health_check_monitor_id' to be a str")
        pulumi.set(__self__, "health_check_monitor_id", health_check_monitor_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if self and not isinstance(self, str):
            raise TypeError("Expected argument 'self' to be a str")
        pulumi.set(__self__, "self", self)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if steering_policy_id and not isinstance(steering_policy_id, str):
            raise TypeError("Expected argument 'steering_policy_id' to be a str")
        pulumi.set(__self__, "steering_policy_id", steering_policy_id)
        if template and not isinstance(template, str):
            raise TypeError("Expected argument 'template' to be a str")
        pulumi.set(__self__, "template", template)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if ttl and not isinstance(ttl, int):
            raise TypeError("Expected argument 'ttl' to be a int")
        pulumi.set(__self__, "ttl", ttl)

    @property
    @pulumi.getter
    def answers(self) -> Sequence['outputs.GetSteeringPolicyAnswerResult']:
        """
        The set of all answers that can potentially issue from the steering policy.
        """
        return pulumi.get(self, "answers")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment containing the steering policy.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A user-friendly name for the steering policy. Does not have to be unique and can be changed. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="healthCheckMonitorId")
    def health_check_monitor_id(self) -> str:
        """
        The OCID of the health check monitor providing health data about the answers of the steering policy. A steering policy answer with `rdata` matching a monitored endpoint will use the health data of that endpoint. A steering policy answer with `rdata` not matching any monitored endpoint will be assumed healthy.
        """
        return pulumi.get(self, "health_check_monitor_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetSteeringPolicyRuleResult']:
        """
        The series of rules that will be processed in sequence to reduce the pool of answers to a response for any given request.
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter
    def self(self) -> str:
        """
        The canonical absolute URL of the resource.
        """
        return pulumi.get(self, "self")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the resource.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="steeringPolicyId")
    def steering_policy_id(self) -> str:
        return pulumi.get(self, "steering_policy_id")

    @property
    @pulumi.getter
    def template(self) -> str:
        """
        A set of predefined rules based on the desired purpose of the steering policy. Each template utilizes Traffic Management's rules in a different order to produce the desired results when answering DNS queries.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the resource was created, expressed in RFC 3339 timestamp format.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter
    def ttl(self) -> int:
        """
        The Time To Live (TTL) for responses from the steering policy, in seconds. If not specified during creation, a value of 30 seconds will be used.
        """
        return pulumi.get(self, "ttl")


class AwaitableGetSteeringPolicyResult(GetSteeringPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSteeringPolicyResult(
            answers=self.answers,
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            health_check_monitor_id=self.health_check_monitor_id,
            id=self.id,
            rules=self.rules,
            self=self.self,
            state=self.state,
            steering_policy_id=self.steering_policy_id,
            template=self.template,
            time_created=self.time_created,
            ttl=self.ttl)


def get_steering_policy(steering_policy_id: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSteeringPolicyResult:
    """
    This data source provides details about a specific Steering Policy resource in Oracle Cloud Infrastructure DNS service.

    Gets information about the specified steering policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_steering_policy = oci.Dns.get_steering_policy(steering_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str steering_policy_id: The OCID of the target steering policy.
    """
    __args__ = dict()
    __args__['steeringPolicyId'] = steering_policy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Dns/getSteeringPolicy:getSteeringPolicy', __args__, opts=opts, typ=GetSteeringPolicyResult).value

    return AwaitableGetSteeringPolicyResult(
        answers=__ret__.answers,
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        health_check_monitor_id=__ret__.health_check_monitor_id,
        id=__ret__.id,
        rules=__ret__.rules,
        self=__ret__.self,
        state=__ret__.state,
        steering_policy_id=__ret__.steering_policy_id,
        template=__ret__.template,
        time_created=__ret__.time_created,
        ttl=__ret__.ttl)


@_utilities.lift_output_func(get_steering_policy)
def get_steering_policy_output(steering_policy_id: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSteeringPolicyResult]:
    """
    This data source provides details about a specific Steering Policy resource in Oracle Cloud Infrastructure DNS service.

    Gets information about the specified steering policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_steering_policy = oci.Dns.get_steering_policy(steering_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str steering_policy_id: The OCID of the target steering policy.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVtapsResult',
    'AwaitableGetVtapsResult',
    'get_vtaps',
    'get_vtaps_output',
]

@pulumi.output_type
class GetVtapsResult:
    """
    A collection of values returned by getVtaps.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, is_vtap_enabled=None, source=None, state=None, target_id=None, target_ip=None, vcn_id=None, vtaps=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_vtap_enabled and not isinstance(is_vtap_enabled, bool):
            raise TypeError("Expected argument 'is_vtap_enabled' to be a bool")
        pulumi.set(__self__, "is_vtap_enabled", is_vtap_enabled)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if target_id and not isinstance(target_id, str):
            raise TypeError("Expected argument 'target_id' to be a str")
        pulumi.set(__self__, "target_id", target_id)
        if target_ip and not isinstance(target_ip, str):
            raise TypeError("Expected argument 'target_ip' to be a str")
        pulumi.set(__self__, "target_ip", target_ip)
        if vcn_id and not isinstance(vcn_id, str):
            raise TypeError("Expected argument 'vcn_id' to be a str")
        pulumi.set(__self__, "vcn_id", vcn_id)
        if vtaps and not isinstance(vtaps, list):
            raise TypeError("Expected argument 'vtaps' to be a list")
        pulumi.set(__self__, "vtaps", vtaps)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the `Vtap` resource.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetVtapsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isVtapEnabled")
    def is_vtap_enabled(self) -> Optional[bool]:
        """
        Used to start or stop a `Vtap` resource.
        """
        return pulumi.get(self, "is_vtap_enabled")

    @property
    @pulumi.getter
    def source(self) -> Optional[str]:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The VTAP's administrative lifecycle state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the destination resource where mirrored packets are sent.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter(name="targetIp")
    def target_ip(self) -> Optional[str]:
        """
        The IP address of the destination resource where mirrored packets are sent.
        """
        return pulumi.get(self, "target_ip")

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN containing the `Vtap` resource.
        """
        return pulumi.get(self, "vcn_id")

    @property
    @pulumi.getter
    def vtaps(self) -> Sequence['outputs.GetVtapsVtapResult']:
        """
        The list of vtaps.
        """
        return pulumi.get(self, "vtaps")


class AwaitableGetVtapsResult(GetVtapsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVtapsResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            is_vtap_enabled=self.is_vtap_enabled,
            source=self.source,
            state=self.state,
            target_id=self.target_id,
            target_ip=self.target_ip,
            vcn_id=self.vcn_id,
            vtaps=self.vtaps)


def get_vtaps(compartment_id: Optional[str] = None,
              display_name: Optional[str] = None,
              filters: Optional[Sequence[pulumi.InputType['GetVtapsFilterArgs']]] = None,
              is_vtap_enabled: Optional[bool] = None,
              source: Optional[str] = None,
              state: Optional[str] = None,
              target_id: Optional[str] = None,
              target_ip: Optional[str] = None,
              vcn_id: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVtapsResult:
    """
    This data source provides the list of Vtaps in Oracle Cloud Infrastructure Core service.

    Lists the virtual test access points (VTAPs) in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vtaps = oci.Core.get_vtaps(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_vtap_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        vcn_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str display_name: A filter to return only resources that match the given display name exactly.
    :param bool is_vtap_enabled: Indicates whether to list all VTAPs or only running VTAPs.
           * When `FALSE`, lists ALL running and stopped VTAPs.
           * When `TRUE`, lists only running VTAPs (VTAPs where isVtapEnabled = `TRUE`).
    :param str source: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VTAP source.
    :param str state: A filter to return only resources that match the given VTAP administrative lifecycle state. The state value is case-insensitive.
    :param str target_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VTAP target.
    :param str target_ip: The IP address of the VTAP target.
    :param str vcn_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['isVtapEnabled'] = is_vtap_enabled
    __args__['source'] = source
    __args__['state'] = state
    __args__['targetId'] = target_id
    __args__['targetIp'] = target_ip
    __args__['vcnId'] = vcn_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getVtaps:getVtaps', __args__, opts=opts, typ=GetVtapsResult).value

    return AwaitableGetVtapsResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        is_vtap_enabled=__ret__.is_vtap_enabled,
        source=__ret__.source,
        state=__ret__.state,
        target_id=__ret__.target_id,
        target_ip=__ret__.target_ip,
        vcn_id=__ret__.vcn_id,
        vtaps=__ret__.vtaps)


@_utilities.lift_output_func(get_vtaps)
def get_vtaps_output(compartment_id: Optional[pulumi.Input[str]] = None,
                     display_name: Optional[pulumi.Input[Optional[str]]] = None,
                     filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetVtapsFilterArgs']]]]] = None,
                     is_vtap_enabled: Optional[pulumi.Input[Optional[bool]]] = None,
                     source: Optional[pulumi.Input[Optional[str]]] = None,
                     state: Optional[pulumi.Input[Optional[str]]] = None,
                     target_id: Optional[pulumi.Input[Optional[str]]] = None,
                     target_ip: Optional[pulumi.Input[Optional[str]]] = None,
                     vcn_id: Optional[pulumi.Input[Optional[str]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVtapsResult]:
    """
    This data source provides the list of Vtaps in Oracle Cloud Infrastructure Core service.

    Lists the virtual test access points (VTAPs) in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vtaps = oci.Core.get_vtaps(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_vtap_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        vcn_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str display_name: A filter to return only resources that match the given display name exactly.
    :param bool is_vtap_enabled: Indicates whether to list all VTAPs or only running VTAPs.
           * When `FALSE`, lists ALL running and stopped VTAPs.
           * When `TRUE`, lists only running VTAPs (VTAPs where isVtapEnabled = `TRUE`).
    :param str source: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VTAP source.
    :param str state: A filter to return only resources that match the given VTAP administrative lifecycle state. The state value is case-insensitive.
    :param str target_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VTAP target.
    :param str target_ip: The IP address of the VTAP target.
    :param str vcn_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataMaskRulesResult',
    'AwaitableGetDataMaskRulesResult',
    'get_data_mask_rules',
    'get_data_mask_rules_output',
]

@pulumi.output_type
class GetDataMaskRulesResult:
    """
    A collection of values returned by getDataMaskRules.
    """
    def __init__(__self__, access_level=None, compartment_id=None, data_mask_rule_collections=None, data_mask_rule_status=None, display_name=None, filters=None, iam_group_id=None, id=None, state=None, target_id=None, target_type=None):
        if access_level and not isinstance(access_level, str):
            raise TypeError("Expected argument 'access_level' to be a str")
        pulumi.set(__self__, "access_level", access_level)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if data_mask_rule_collections and not isinstance(data_mask_rule_collections, list):
            raise TypeError("Expected argument 'data_mask_rule_collections' to be a list")
        pulumi.set(__self__, "data_mask_rule_collections", data_mask_rule_collections)
        if data_mask_rule_status and not isinstance(data_mask_rule_status, str):
            raise TypeError("Expected argument 'data_mask_rule_status' to be a str")
        pulumi.set(__self__, "data_mask_rule_status", data_mask_rule_status)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if iam_group_id and not isinstance(iam_group_id, str):
            raise TypeError("Expected argument 'iam_group_id' to be a str")
        pulumi.set(__self__, "iam_group_id", iam_group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if target_id and not isinstance(target_id, str):
            raise TypeError("Expected argument 'target_id' to be a str")
        pulumi.set(__self__, "target_id", target_id)
        if target_type and not isinstance(target_type, str):
            raise TypeError("Expected argument 'target_type' to be a str")
        pulumi.set(__self__, "target_type", target_type)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[str]:
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier where the resource is created.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dataMaskRuleCollections")
    def data_mask_rule_collections(self) -> Sequence['outputs.GetDataMaskRulesDataMaskRuleCollectionResult']:
        """
        The list of data_mask_rule_collection.
        """
        return pulumi.get(self, "data_mask_rule_collections")

    @property
    @pulumi.getter(name="dataMaskRuleStatus")
    def data_mask_rule_status(self) -> Optional[str]:
        """
        The status of the dataMaskRule.
        """
        return pulumi.get(self, "data_mask_rule_status")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        Data Mask Rule Identifier, can be renamed.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDataMaskRulesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="iamGroupId")
    def iam_group_id(self) -> Optional[str]:
        """
        IAM Group id associated with the data mask rule
        """
        return pulumi.get(self, "iam_group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the DataMaskRule.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> Optional[str]:
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> Optional[str]:
        return pulumi.get(self, "target_type")


class AwaitableGetDataMaskRulesResult(GetDataMaskRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataMaskRulesResult(
            access_level=self.access_level,
            compartment_id=self.compartment_id,
            data_mask_rule_collections=self.data_mask_rule_collections,
            data_mask_rule_status=self.data_mask_rule_status,
            display_name=self.display_name,
            filters=self.filters,
            iam_group_id=self.iam_group_id,
            id=self.id,
            state=self.state,
            target_id=self.target_id,
            target_type=self.target_type)


def get_data_mask_rules(access_level: Optional[str] = None,
                        compartment_id: Optional[str] = None,
                        data_mask_rule_status: Optional[str] = None,
                        display_name: Optional[str] = None,
                        filters: Optional[Sequence[pulumi.InputType['GetDataMaskRulesFilterArgs']]] = None,
                        iam_group_id: Optional[str] = None,
                        state: Optional[str] = None,
                        target_id: Optional[str] = None,
                        target_type: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataMaskRulesResult:
    """
    This data source provides the list of Data Mask Rules in Oracle Cloud Infrastructure Cloud Guard service.

    Returns a list of all Data Mask Rules in the root 'compartmentId' passed.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_mask_rules = oci.CloudGuard.get_data_mask_rules(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        data_mask_rule_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        iam_group_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are `RESTRICTED` and `ACCESSIBLE`. Default is `RESTRICTED`. Setting this to `ACCESSIBLE` returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to `RESTRICTED` permissions are checked and no partial results are displayed.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str data_mask_rule_status: The status of the dataMaskRule.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str iam_group_id: OCID of iamGroup
    :param str state: The field life cycle state. Only one state can be provided. Default value for state is active. If no value is specified state is active.
    :param str target_id: OCID of target
    :param str target_type: Type of target
    """
    __args__ = dict()
    __args__['accessLevel'] = access_level
    __args__['compartmentId'] = compartment_id
    __args__['dataMaskRuleStatus'] = data_mask_rule_status
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['iamGroupId'] = iam_group_id
    __args__['state'] = state
    __args__['targetId'] = target_id
    __args__['targetType'] = target_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:CloudGuard/getDataMaskRules:getDataMaskRules', __args__, opts=opts, typ=GetDataMaskRulesResult).value

    return AwaitableGetDataMaskRulesResult(
        access_level=__ret__.access_level,
        compartment_id=__ret__.compartment_id,
        data_mask_rule_collections=__ret__.data_mask_rule_collections,
        data_mask_rule_status=__ret__.data_mask_rule_status,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        iam_group_id=__ret__.iam_group_id,
        id=__ret__.id,
        state=__ret__.state,
        target_id=__ret__.target_id,
        target_type=__ret__.target_type)


@_utilities.lift_output_func(get_data_mask_rules)
def get_data_mask_rules_output(access_level: Optional[pulumi.Input[Optional[str]]] = None,
                               compartment_id: Optional[pulumi.Input[str]] = None,
                               data_mask_rule_status: Optional[pulumi.Input[Optional[str]]] = None,
                               display_name: Optional[pulumi.Input[Optional[str]]] = None,
                               filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDataMaskRulesFilterArgs']]]]] = None,
                               iam_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                               state: Optional[pulumi.Input[Optional[str]]] = None,
                               target_id: Optional[pulumi.Input[Optional[str]]] = None,
                               target_type: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataMaskRulesResult]:
    """
    This data source provides the list of Data Mask Rules in Oracle Cloud Infrastructure Cloud Guard service.

    Returns a list of all Data Mask Rules in the root 'compartmentId' passed.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_mask_rules = oci.CloudGuard.get_data_mask_rules(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        data_mask_rule_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        iam_group_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are `RESTRICTED` and `ACCESSIBLE`. Default is `RESTRICTED`. Setting this to `ACCESSIBLE` returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to `RESTRICTED` permissions are checked and no partial results are displayed.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str data_mask_rule_status: The status of the dataMaskRule.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str iam_group_id: OCID of iamGroup
    :param str state: The field life cycle state. Only one state can be provided. Default value for state is active. If no value is specified state is active.
    :param str target_id: OCID of target
    :param str target_type: Type of target
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVaultReplicasResult',
    'AwaitableGetVaultReplicasResult',
    'get_vault_replicas',
    'get_vault_replicas_output',
]

@pulumi.output_type
class GetVaultReplicasResult:
    """
    A collection of values returned by getVaultReplicas.
    """
    def __init__(__self__, filters=None, id=None, vault_id=None, vault_replicas=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if vault_id and not isinstance(vault_id, str):
            raise TypeError("Expected argument 'vault_id' to be a str")
        pulumi.set(__self__, "vault_id", vault_id)
        if vault_replicas and not isinstance(vault_replicas, list):
            raise TypeError("Expected argument 'vault_replicas' to be a list")
        pulumi.set(__self__, "vault_replicas", vault_replicas)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetVaultReplicasFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> str:
        return pulumi.get(self, "vault_id")

    @property
    @pulumi.getter(name="vaultReplicas")
    def vault_replicas(self) -> Sequence['outputs.GetVaultReplicasVaultReplicaResult']:
        """
        The list of vault_replicas.
        """
        return pulumi.get(self, "vault_replicas")


class AwaitableGetVaultReplicasResult(GetVaultReplicasResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVaultReplicasResult(
            filters=self.filters,
            id=self.id,
            vault_id=self.vault_id,
            vault_replicas=self.vault_replicas)


def get_vault_replicas(filters: Optional[Sequence[pulumi.InputType['GetVaultReplicasFilterArgs']]] = None,
                       vault_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVaultReplicasResult:
    """
    This data source provides the list of Vault Replicas in Oracle Cloud Infrastructure Kms service.

    Lists the replicas for a vault

    As a provisioning operation, this call is subject to a Key Management limit that applies to
    the total number of requests across all provisioning write operations. Key Management might
    throttle this call to reject an otherwise valid request when the total rate of provisioning
    write operations exceeds 10 requests per second for a given tenancy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vault_replicas = oci.Kms.get_vault_replicas(vault_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str vault_id: The OCID of the vault.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['vaultId'] = vault_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Kms/getVaultReplicas:getVaultReplicas', __args__, opts=opts, typ=GetVaultReplicasResult).value

    return AwaitableGetVaultReplicasResult(
        filters=__ret__.filters,
        id=__ret__.id,
        vault_id=__ret__.vault_id,
        vault_replicas=__ret__.vault_replicas)


@_utilities.lift_output_func(get_vault_replicas)
def get_vault_replicas_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetVaultReplicasFilterArgs']]]]] = None,
                              vault_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVaultReplicasResult]:
    """
    This data source provides the list of Vault Replicas in Oracle Cloud Infrastructure Kms service.

    Lists the replicas for a vault

    As a provisioning operation, this call is subject to a Key Management limit that applies to
    the total number of requests across all provisioning write operations. Key Management might
    throttle this call to reject an otherwise valid request when the total rate of provisioning
    write operations exceeds 10 requests per second for a given tenancy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vault_replicas = oci.Kms.get_vault_replicas(vault_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str vault_id: The OCID of the vault.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitoredResourcesListMemberArgs', 'MonitoredResourcesListMember']

@pulumi.input_type
class MonitoredResourcesListMemberArgs:
    def __init__(__self__, *,
                 monitored_resource_id: pulumi.Input[str],
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 limit_level: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a MonitoredResourcesListMember resource.
        :param pulumi.Input[str] monitored_resource_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[int] limit_level: The field which determines the depth of hierarchy while searching for members.
        """
        pulumi.set(__self__, "monitored_resource_id", monitored_resource_id)
        if destination_resource_id is not None:
            pulumi.set(__self__, "destination_resource_id", destination_resource_id)
        if limit_level is not None:
            pulumi.set(__self__, "limit_level", limit_level)

    @property
    @pulumi.getter(name="monitoredResourceId")
    def monitored_resource_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "monitored_resource_id")

    @monitored_resource_id.setter
    def monitored_resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "monitored_resource_id", value)

    @property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "destination_resource_id")

    @destination_resource_id.setter
    def destination_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_id", value)

    @property
    @pulumi.getter(name="limitLevel")
    def limit_level(self) -> Optional[pulumi.Input[int]]:
        """
        The field which determines the depth of hierarchy while searching for members.
        """
        return pulumi.get(self, "limit_level")

    @limit_level.setter
    def limit_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit_level", value)


@pulumi.input_type
class _MonitoredResourcesListMemberState:
    def __init__(__self__, *,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 items: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesListMemberItemArgs']]]] = None,
                 limit_level: Optional[pulumi.Input[int]] = None,
                 monitored_resource_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MonitoredResourcesListMember resources.
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesListMemberItemArgs']]] items: List of member resources.
        :param pulumi.Input[int] limit_level: The field which determines the depth of hierarchy while searching for members.
        :param pulumi.Input[str] monitored_resource_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if destination_resource_id is not None:
            pulumi.set(__self__, "destination_resource_id", destination_resource_id)
        if items is not None:
            pulumi.set(__self__, "items", items)
        if limit_level is not None:
            pulumi.set(__self__, "limit_level", limit_level)
        if monitored_resource_id is not None:
            pulumi.set(__self__, "monitored_resource_id", monitored_resource_id)

    @property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "destination_resource_id")

    @destination_resource_id.setter
    def destination_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_id", value)

    @property
    @pulumi.getter
    def items(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesListMemberItemArgs']]]]:
        """
        List of member resources.
        """
        return pulumi.get(self, "items")

    @items.setter
    def items(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesListMemberItemArgs']]]]):
        pulumi.set(self, "items", value)

    @property
    @pulumi.getter(name="limitLevel")
    def limit_level(self) -> Optional[pulumi.Input[int]]:
        """
        The field which determines the depth of hierarchy while searching for members.
        """
        return pulumi.get(self, "limit_level")

    @limit_level.setter
    def limit_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit_level", value)

    @property
    @pulumi.getter(name="monitoredResourceId")
    def monitored_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "monitored_resource_id")

    @monitored_resource_id.setter
    def monitored_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitored_resource_id", value)


class MonitoredResourcesListMember(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 limit_level: Optional[pulumi.Input[int]] = None,
                 monitored_resource_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Monitored Resources List Member resource in Oracle Cloud Infrastructure Stack Monitoring service.

        List the member resources for the given monitored resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_monitored_resources_list_member = oci.stack_monitoring.MonitoredResourcesListMember("testMonitoredResourcesListMember",
            monitored_resource_id=oci_stack_monitoring_monitored_resource["test_monitored_resource"]["id"],
            destination_resource_id=oci_stack_monitoring_destination_resource["test_destination_resource"]["id"],
            limit_level=var["monitored_resources_list_member_limit_level"])
        ```

        ## Import

        MonitoredResourcesListMembers can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/monitoredResourcesListMember:MonitoredResourcesListMember test_monitored_resources_list_member "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[int] limit_level: The field which determines the depth of hierarchy while searching for members.
        :param pulumi.Input[str] monitored_resource_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitoredResourcesListMemberArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Monitored Resources List Member resource in Oracle Cloud Infrastructure Stack Monitoring service.

        List the member resources for the given monitored resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_monitored_resources_list_member = oci.stack_monitoring.MonitoredResourcesListMember("testMonitoredResourcesListMember",
            monitored_resource_id=oci_stack_monitoring_monitored_resource["test_monitored_resource"]["id"],
            destination_resource_id=oci_stack_monitoring_destination_resource["test_destination_resource"]["id"],
            limit_level=var["monitored_resources_list_member_limit_level"])
        ```

        ## Import

        MonitoredResourcesListMembers can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/monitoredResourcesListMember:MonitoredResourcesListMember test_monitored_resources_list_member "id"
        ```

        :param str resource_name: The name of the resource.
        :param MonitoredResourcesListMemberArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitoredResourcesListMemberArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 limit_level: Optional[pulumi.Input[int]] = None,
                 monitored_resource_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitoredResourcesListMemberArgs.__new__(MonitoredResourcesListMemberArgs)

            __props__.__dict__["destination_resource_id"] = destination_resource_id
            __props__.__dict__["limit_level"] = limit_level
            if monitored_resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'monitored_resource_id'")
            __props__.__dict__["monitored_resource_id"] = monitored_resource_id
            __props__.__dict__["items"] = None
        super(MonitoredResourcesListMember, __self__).__init__(
            'oci:StackMonitoring/monitoredResourcesListMember:MonitoredResourcesListMember',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            destination_resource_id: Optional[pulumi.Input[str]] = None,
            items: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoredResourcesListMemberItemArgs']]]]] = None,
            limit_level: Optional[pulumi.Input[int]] = None,
            monitored_resource_id: Optional[pulumi.Input[str]] = None) -> 'MonitoredResourcesListMember':
        """
        Get an existing MonitoredResourcesListMember resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoredResourcesListMemberItemArgs']]]] items: List of member resources.
        :param pulumi.Input[int] limit_level: The field which determines the depth of hierarchy while searching for members.
        :param pulumi.Input[str] monitored_resource_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitoredResourcesListMemberState.__new__(_MonitoredResourcesListMemberState)

        __props__.__dict__["destination_resource_id"] = destination_resource_id
        __props__.__dict__["items"] = items
        __props__.__dict__["limit_level"] = limit_level
        __props__.__dict__["monitored_resource_id"] = monitored_resource_id
        return MonitoredResourcesListMember(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> pulumi.Output[Optional[str]]:
        """
        Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "destination_resource_id")

    @property
    @pulumi.getter
    def items(self) -> pulumi.Output[Sequence['outputs.MonitoredResourcesListMemberItem']]:
        """
        List of member resources.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="limitLevel")
    def limit_level(self) -> pulumi.Output[Optional[int]]:
        """
        The field which determines the depth of hierarchy while searching for members.
        """
        return pulumi.get(self, "limit_level")

    @property
    @pulumi.getter(name="monitoredResourceId")
    def monitored_resource_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of monitored resource.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "monitored_resource_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRepositoryCommitsResult',
    'AwaitableGetRepositoryCommitsResult',
    'get_repository_commits',
    'get_repository_commits_output',
]

@pulumi.output_type
class GetRepositoryCommitsResult:
    """
    A collection of values returned by getRepositoryCommits.
    """
    def __init__(__self__, author_name=None, commit_message=None, exclude_ref_name=None, file_path=None, filters=None, id=None, ref_name=None, repository_commit_collections=None, repository_id=None, timestamp_greater_than_or_equal_to=None, timestamp_less_than_or_equal_to=None):
        if author_name and not isinstance(author_name, str):
            raise TypeError("Expected argument 'author_name' to be a str")
        pulumi.set(__self__, "author_name", author_name)
        if commit_message and not isinstance(commit_message, str):
            raise TypeError("Expected argument 'commit_message' to be a str")
        pulumi.set(__self__, "commit_message", commit_message)
        if exclude_ref_name and not isinstance(exclude_ref_name, str):
            raise TypeError("Expected argument 'exclude_ref_name' to be a str")
        pulumi.set(__self__, "exclude_ref_name", exclude_ref_name)
        if file_path and not isinstance(file_path, str):
            raise TypeError("Expected argument 'file_path' to be a str")
        pulumi.set(__self__, "file_path", file_path)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ref_name and not isinstance(ref_name, str):
            raise TypeError("Expected argument 'ref_name' to be a str")
        pulumi.set(__self__, "ref_name", ref_name)
        if repository_commit_collections and not isinstance(repository_commit_collections, list):
            raise TypeError("Expected argument 'repository_commit_collections' to be a list")
        pulumi.set(__self__, "repository_commit_collections", repository_commit_collections)
        if repository_id and not isinstance(repository_id, str):
            raise TypeError("Expected argument 'repository_id' to be a str")
        pulumi.set(__self__, "repository_id", repository_id)
        if timestamp_greater_than_or_equal_to and not isinstance(timestamp_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'timestamp_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "timestamp_greater_than_or_equal_to", timestamp_greater_than_or_equal_to)
        if timestamp_less_than_or_equal_to and not isinstance(timestamp_less_than_or_equal_to, str):
            raise TypeError("Expected argument 'timestamp_less_than_or_equal_to' to be a str")
        pulumi.set(__self__, "timestamp_less_than_or_equal_to", timestamp_less_than_or_equal_to)

    @property
    @pulumi.getter(name="authorName")
    def author_name(self) -> Optional[str]:
        """
        Name of the author of the repository.
        """
        return pulumi.get(self, "author_name")

    @property
    @pulumi.getter(name="commitMessage")
    def commit_message(self) -> Optional[str]:
        """
        The commit message.
        """
        return pulumi.get(self, "commit_message")

    @property
    @pulumi.getter(name="excludeRefName")
    def exclude_ref_name(self) -> Optional[str]:
        return pulumi.get(self, "exclude_ref_name")

    @property
    @pulumi.getter(name="filePath")
    def file_path(self) -> Optional[str]:
        return pulumi.get(self, "file_path")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetRepositoryCommitsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="refName")
    def ref_name(self) -> Optional[str]:
        return pulumi.get(self, "ref_name")

    @property
    @pulumi.getter(name="repositoryCommitCollections")
    def repository_commit_collections(self) -> Sequence['outputs.GetRepositoryCommitsRepositoryCommitCollectionResult']:
        """
        The list of repository_commit_collection.
        """
        return pulumi.get(self, "repository_commit_collections")

    @property
    @pulumi.getter(name="repositoryId")
    def repository_id(self) -> str:
        return pulumi.get(self, "repository_id")

    @property
    @pulumi.getter(name="timestampGreaterThanOrEqualTo")
    def timestamp_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "timestamp_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timestampLessThanOrEqualTo")
    def timestamp_less_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "timestamp_less_than_or_equal_to")


class AwaitableGetRepositoryCommitsResult(GetRepositoryCommitsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryCommitsResult(
            author_name=self.author_name,
            commit_message=self.commit_message,
            exclude_ref_name=self.exclude_ref_name,
            file_path=self.file_path,
            filters=self.filters,
            id=self.id,
            ref_name=self.ref_name,
            repository_commit_collections=self.repository_commit_collections,
            repository_id=self.repository_id,
            timestamp_greater_than_or_equal_to=self.timestamp_greater_than_or_equal_to,
            timestamp_less_than_or_equal_to=self.timestamp_less_than_or_equal_to)


def get_repository_commits(author_name: Optional[str] = None,
                           commit_message: Optional[str] = None,
                           exclude_ref_name: Optional[str] = None,
                           file_path: Optional[str] = None,
                           filters: Optional[Sequence[pulumi.InputType['GetRepositoryCommitsFilterArgs']]] = None,
                           ref_name: Optional[str] = None,
                           repository_id: Optional[str] = None,
                           timestamp_greater_than_or_equal_to: Optional[str] = None,
                           timestamp_less_than_or_equal_to: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryCommitsResult:
    """
    This data source provides the list of Repository Commits in Oracle Cloud Infrastructure Devops service.

    Returns a list of commits.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_repository_commits = oci.DevOps.get_repository_commits(repository_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        author_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        commit_message=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        exclude_ref_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        file_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        ref_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        timestamp_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        timestamp_less_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str author_name: A filter to return any commits that are pushed by the requested author.
    :param str commit_message: A filter to return any commits that contains the given message.
    :param str exclude_ref_name: A filter to exclude commits that match the given reference name.
    :param str file_path: A filter to return only commits that affect any of the specified paths.
    :param str ref_name: A filter to return only resources that match the given reference name.
    :param str repository_id: Unique repository identifier.
    :param str timestamp_greater_than_or_equal_to: A filter to return commits only created after the specified timestamp value.
    :param str timestamp_less_than_or_equal_to: A filter to return commits only created before the specified timestamp value.
    """
    __args__ = dict()
    __args__['authorName'] = author_name
    __args__['commitMessage'] = commit_message
    __args__['excludeRefName'] = exclude_ref_name
    __args__['filePath'] = file_path
    __args__['filters'] = filters
    __args__['refName'] = ref_name
    __args__['repositoryId'] = repository_id
    __args__['timestampGreaterThanOrEqualTo'] = timestamp_greater_than_or_equal_to
    __args__['timestampLessThanOrEqualTo'] = timestamp_less_than_or_equal_to
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DevOps/getRepositoryCommits:getRepositoryCommits', __args__, opts=opts, typ=GetRepositoryCommitsResult).value

    return AwaitableGetRepositoryCommitsResult(
        author_name=__ret__.author_name,
        commit_message=__ret__.commit_message,
        exclude_ref_name=__ret__.exclude_ref_name,
        file_path=__ret__.file_path,
        filters=__ret__.filters,
        id=__ret__.id,
        ref_name=__ret__.ref_name,
        repository_commit_collections=__ret__.repository_commit_collections,
        repository_id=__ret__.repository_id,
        timestamp_greater_than_or_equal_to=__ret__.timestamp_greater_than_or_equal_to,
        timestamp_less_than_or_equal_to=__ret__.timestamp_less_than_or_equal_to)


@_utilities.lift_output_func(get_repository_commits)
def get_repository_commits_output(author_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  commit_message: Optional[pulumi.Input[Optional[str]]] = None,
                                  exclude_ref_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  file_path: Optional[pulumi.Input[Optional[str]]] = None,
                                  filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetRepositoryCommitsFilterArgs']]]]] = None,
                                  ref_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  repository_id: Optional[pulumi.Input[str]] = None,
                                  timestamp_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                  timestamp_less_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRepositoryCommitsResult]:
    """
    This data source provides the list of Repository Commits in Oracle Cloud Infrastructure Devops service.

    Returns a list of commits.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_repository_commits = oci.DevOps.get_repository_commits(repository_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        author_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        commit_message=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        exclude_ref_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        file_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        ref_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        timestamp_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        timestamp_less_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str author_name: A filter to return any commits that are pushed by the requested author.
    :param str commit_message: A filter to return any commits that contains the given message.
    :param str exclude_ref_name: A filter to exclude commits that match the given reference name.
    :param str file_path: A filter to return only commits that affect any of the specified paths.
    :param str ref_name: A filter to return only resources that match the given reference name.
    :param str repository_id: Unique repository identifier.
    :param str timestamp_greater_than_or_equal_to: A filter to return commits only created after the specified timestamp value.
    :param str timestamp_less_than_or_equal_to: A filter to return commits only created before the specified timestamp value.
    """
    ...
